==> net.bluemind.core.container.service-4.9.3879.jar: net/bluemind/core/container/service/ContainersByLocationFactory.java <==
/* BEGIN LICENSE
 * Copyright © Blue Mind SAS, 2012-2024
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.core.container.service;

import javax.sql.DataSource;

import net.bluemind.core.api.fault.ServerFault;
import net.bluemind.core.container.api.IInternalContainersByLocation;
import net.bluemind.core.container.service.internal.ContainersByLocation;
import net.bluemind.core.rest.BmContext;
import net.bluemind.core.rest.ServerSideServiceProvider;

public class ContainersByLocationFactory
		implements ServerSideServiceProvider.IServerSideServiceFactory<IInternalContainersByLocation> {

	@Override
	public Class<IInternalContainersByLocation> factoryClass() {
		return IInternalContainersByLocation.class;
	}

	@Override
	public IInternalContainersByLocation instance(BmContext context, String... params) throws ServerFault {
		if (params == null || params.length < 1) {
			throw new ServerFault("1 parameter expected, datalocation (got " + params + ")");
		}

		String dataLocation = params[0];
		DataSource dataSource = context.getMailboxDataSource(dataLocation);

		return new ContainersByLocation(context, dataSource);
	}
}

==> net.bluemind.core.container.service-5.5.3112.jar: net/bluemind/core/container/service/ContainersByLocationFactory.java <==
/* BEGIN LICENSE
 * Copyright © Blue Mind SAS, 2012-2024
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.core.container.service;

import javax.sql.DataSource;

import net.bluemind.core.api.fault.ServerFault;
import net.bluemind.core.container.api.IInternalContainersByLocation;
import net.bluemind.core.container.model.DataLocation;
import net.bluemind.core.container.service.internal.ContainersByLocation;
import net.bluemind.core.rest.BmContext;
import net.bluemind.core.rest.ServerSideServiceProvider;

public class ContainersByLocationFactory
		implements ServerSideServiceProvider.IServerSideServiceFactory<IInternalContainersByLocation> {

	@Override
	public Class<IInternalContainersByLocation> factoryClass() {
		return IInternalContainersByLocation.class;
	}

	@Override
	public IInternalContainersByLocation instance(BmContext context, String... params) throws ServerFault {
		if (params == null || params.length < 1) {
			throw new ServerFault("1 parameter expected, datalocation (got " + params + ")");
		}

		String serverUid = params[0];
		DataSource dataSource = context.getMailboxDataSource(serverUid);
		DataLocation dataLocation = DataLocation.of(serverUid);
		return new ContainersByLocation(context, dataSource, dataLocation);
	}
}
